==> flask-rebar-1.0.8.tar.gz: flask-rebar-1.0.8/flask_rebar/swagger_generation/swagger_words.py <==
"""
    Swagger Words
    ~~~~~~~~~~~~~

    Python friendly aliases to reserved Swagger words.

    :copyright: Copyright 2018 PlanGrid, Inc., see AUTHORS.
    :license: MIT, see LICENSE for details.
"""
from __future__ import unicode_literals

additional_properties = 'additionalProperties'
all_of = 'allOf'
allow_empty_value = 'allowEmptyValue'
api_key = 'apiKey'
array = 'array'
basic = 'basic'
binary = 'binary'
body = 'body'
boolean = 'boolean'
byte = 'byte'
collection_format = 'collectionFormat'
consumes = 'consumes'
csv = 'csv'
date = 'date'
date_time = 'date-time'
default = 'default'
definitions = 'definitions'
description = 'description'
double = 'double'
enum = 'enum'
exclusive_maximum = 'exclusiveMaximum'
exclusive_minimum = 'exclusiveMinimum'
float_ = 'float'
format_ = 'format'
header = 'header'
host = 'host'
in_ = 'in'
info = 'info'
integer = 'integer'
int32 = 'int32'
int64 = 'int64'
items = 'items'
max_items = 'maxItems'
max_length = 'maxLength'
max_properties = 'maxProperties'
maximum = 'maximum'
min_items = 'minItems'
min_length = 'minLength'
min_properties = 'minProperties'
minimum = 'minimum'
multi = 'multi'
multiple_of = 'multipleOf'
name = 'name'
nullable = 'x-nullable'
number = 'number'
oauth2 = 'oauth2'
object_ = 'object'
operation_id = 'operationId'
parameters = 'parameters'
passowrd = 'password'
path = 'path'
paths = 'paths'
pattern = 'pattern'
produces = 'produces'
properties = 'properties'
query = 'query'
ref = '$ref'
required = 'required'
responses = 'responses'
schema = 'schema'
schemes = 'schemes'
security = 'security'
security_definitions = 'securityDefinitions'
string = 'string'
swagger = 'swagger'
title = 'title'
type_ = 'type'
unique_items = 'uniqueItems'
uuid = 'uuid'
version = 'version'

==> flask-rebar-1.3.0.tar.gz: flask-rebar-1.3.0/flask_rebar/swagger_generation/swagger_words.py <==
"""
    Swagger Words
    ~~~~~~~~~~~~~

    Python friendly aliases to reserved Swagger words.

    :copyright: Copyright 2018 PlanGrid, Inc., see AUTHORS.
    :license: MIT, see LICENSE for details.
"""
from __future__ import unicode_literals

additional_properties = 'additionalProperties'
all_of = 'allOf'
allow_empty_value = 'allowEmptyValue'
api_key = 'apiKey'
array = 'array'
basic = 'basic'
binary = 'binary'
body = 'body'
boolean = 'boolean'
byte = 'byte'
collection_format = 'collectionFormat'
consumes = 'consumes'
csv = 'csv'
date = 'date'
date_time = 'date-time'
default = 'default'
definitions = 'definitions'
description = 'description'
double = 'double'
enum = 'enum'
exclusive_maximum = 'exclusiveMaximum'
exclusive_minimum = 'exclusiveMinimum'
float_ = 'float'
format_ = 'format'
header = 'header'
host = 'host'
in_ = 'in'
info = 'info'
integer = 'integer'
int32 = 'int32'
int64 = 'int64'
items = 'items'
max_items = 'maxItems'
max_length = 'maxLength'
max_properties = 'maxProperties'
maximum = 'maximum'
min_items = 'minItems'
min_length = 'minLength'
min_properties = 'minProperties'
minimum = 'minimum'
multi = 'multi'
multiple_of = 'multipleOf'
name = 'name'
nullable = 'x-nullable'
number = 'number'
oauth2 = 'oauth2'
object_ = 'object'
operation_id = 'operationId'
parameters = 'parameters'
password = 'password'
path = 'path'
paths = 'paths'
pattern = 'pattern'
produces = 'produces'
properties = 'properties'
query = 'query'
ref = '$ref'
required = 'required'
responses = 'responses'
schema = 'schema'
schemes = 'schemes'
security = 'security'
security_definitions = 'securityDefinitions'
string = 'string'
swagger = 'swagger'
title = 'title'
type_ = 'type'
unique_items = 'uniqueItems'
uuid = 'uuid'
version = 'version'
